@@ -310,6 +310,18 @@ fn test_cli_version() {
     check_with_args(&["the", "--version", "flag wins over arguments"]);
 }
 
+#[test]
+fn test_example_gpio() {
+    check(
+        bin_path("endbasic"),
+        &["--interactive", &src_str("cli/tests/examples/gpio.bas")],
+        0,
+        Behavior::File(src_path("cli/tests/examples/gpio.in")),
+        Behavior::File(src_path("cli/tests/examples/gpio.out")),
+        Behavior::Null,
+    );
+}
+
 #[test]
 fn test_example_guess() {
     check(
@@ -394,6 +406,18 @@ fn test_lang_lexer_error() {
     );
 }
 
+#[test]
+fn test_lang_matrix() {
+    check(
+        bin_path("endbasic"),
+        &[&src_str("cli/tests/lang/matrix.bas")],
+        0,
+        Behavior::Null,
+        Behavior::File(src_path("cli/tests/lang/matrix.out")),
+        Behavior::Null,
+    );
+}
+
 #[test]
 fn test_lang_parser_error() {
     check(
